# PyEmission
PyEmission is a Python library for the estimation of gasoline vehicular emissions and fuel consumption. This tool covers a wide range of light-duty motor vehicles including motorcycle, passenger car, passenger truck, and light commercial truck. The tool only takes second-by-second driving cycle and vehicle characteristics data as inputs and generates results of vehicular emissions (CO2, CO, NOx, and HC) and fuel consumption. This tool can estimate both tailpipe and corresponding upstream (Well-To-Pump) emissions.

# PyEmission
Python Library for Vehicular Emission Estimation (PyEmission)

PyEmission is a Python library for estimation of gasoline vehicular emissions and fuel consumption. This tool covers a wide range of light duty motor vehicles including passenger car, SUV, passenger truck, and light commercial truck. The tool only takes second-by-second driving cycle and vehicle characteristics data as inputs and generate results of vehicular emissions (CO2, CO, NOx, and HC) and fuel consumption.

A detailed description of this software methodology can be found in this [Journal Article](https://doi.org/10.1016/j.jclepro.2021.128931).

# User Manual
Please find the user manual [here](https://github.com/IdahoLabResearch/PyEmission/blob/main/PyEmission%20user%20manual.pdf)

 
### Other Software
Idaho National Laboratory is a cutting edge research facility which is a constantly producing high quality research and software. Feel free to take a look at our other software and scientific offerings at:

[Primary Technology Offerings Page](https://www.inl.gov/inl-initiatives/technology-deployment)

[Supported Open Source Software](https://github.com/idaholab)

[Raw Experiment Open Source Software](https://github.com/IdahoLabResearch)

[Unsupported Open Source Software](https://github.com/IdahoLabCuttingBoard)

### License
You may obtain a copy of the License at https://opensource.org/licenses/Apache-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.



Licensing
-----
This software is licensed under the terms you may find in the file named "LICENSE" in this [GitHub](https://github.com/IdahoLabResearch/PyEmission) repository.


Developers
-----
By contributing to this software project, you are agreeing to the following terms and conditions for your contributions:

You agree your contributions are submitted under the Apache-2 license. You represent you are authorized to make the contributions and grant the license. If your employer has rights to intellectual property that includes your contributions, you represent that you have received permission to make contributions and grant the required license on behalf of that employer.

Authors
-----
Md Mamunur Rahman (mdmamunur.rahman@inl.gov)

Ruby Thuy Nguyen (ruby.nguyen@inl.gov)